@@ -33,9 +33,10 @@
 #  define OKTETAKASTENCONTROLLERS_DEPRECATED_NO_EXPORT OKTETAKASTENCONTROLLERS_NO_EXPORT OKTETAKASTENCONTROLLERS_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define OKTETAKASTENCONTROLLERS_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef OKTETAKASTENCONTROLLERS_NO_DEPRECATED
+#    define OKTETAKASTENCONTROLLERS_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
